# Credits

## Development Lead

[//]: # ({# pkglts, doc)

{%- for name, email in base.authors -%}
* {{ name }}, <{{ email }}>
{% endfor -%}

[//]: # (#})

## Contributors

None yet. Why not be the first?
